=== modified file 'tests/lib/randgen/randgen_test_execution.py'
--- tests/lib/randgen/randgen_test_execution.py	2011-04-03 16:54:43 +0000
+++ tests/lib/randgen/randgen_test_execution.py	2011-06-01 23:31:52 +0000
@@ -23,7 +23,7 @@
     code related to the execution of dtr test cases 
     
     We are provided access to a testManager with 
-    dtr-specific testCases.  We contact teh executionManager
+    randgen-specific testCases.  We contact the executionManager
     to produce the system and server configurations we need
     to execute a test.
 
@@ -38,16 +38,12 @@
 import lib.test_mgmt.test_execution as test_execution
 
 class randgenTestExecutor(test_execution.testExecutor):
-    """ dtr-specific testExecutor 
-        We currently execute by sending test-case
-        data to client/randgen...for now
+    """ randgen-specific testExecutor 
 
     """
   
     def execute_testCase (self):
-        """ Execute a dtr testCase via calls to randgen (boo)
-            Eventually, we will replace randgen with pythonic
-            goodness, but we have these classes stored here for the moment
+        """ Execute a randgen testCase
 
         """
         test_execution.testExecutor.execute_testCase(self)

=== modified file 'tests/lib/randgen/randgen_test_management.py'
--- tests/lib/randgen/randgen_test_management.py	2011-03-17 06:31:49 +0000
+++ tests/lib/randgen/randgen_test_management.py	2011-06-01 23:31:52 +0000
@@ -43,7 +43,8 @@
     """
     def __init__( self, system_manager, name=None
                 , fullname = None, server_requirements=[[]]
-                , comment=None, test_command=None, debug=False ):
+                , comment=None, test_command=None, cnf_path=None
+                , debug=False ):
         self.system_manager = system_manager
         self.logging = self.system_manager.logging
         self.skip_keys = ['system_manager','logging']
@@ -54,6 +55,7 @@
         self.comment = comment
         self.server_requirements = server_requirements
         self.test_command = test_command
+        self.cnf_path = cnf_path
         
         if debug:
             self.system_manager.logging.debug_class(self)
@@ -131,6 +133,7 @@
                        , fullname = "%s.%s" %(suite_name, test_name)
                        , server_requirements = server_requirements
                        , test_command = test_command
+                       , cnf_path = testfile
                        , debug = self.debug )
 
         #sys.exit(0)

=== modified file 'tests/lib/sys_mgmt/logging_management.py'
--- tests/lib/sys_mgmt/logging_management.py	2011-04-22 21:05:12 +0000
+++ tests/lib/sys_mgmt/logging_management.py	2011-06-01 23:31:52 +0000
@@ -89,7 +89,8 @@
 
 
     def test_report( self, test_name, test_status
-                   , execution_time, additional_output=None):
+                   , execution_time, additional_output = None
+                   , report_output = False):
         """ We use this method to deal with writing out the test report
 
         """
@@ -100,7 +101,7 @@
         msg = self.report_fmt.format( test_name, test_status
                                     , execution_time)
         self._write_message("", msg)
-        if additional_output and test_status != '[ pass ]':
+        if additional_output and report_output:
             additional_output=additional_output.split('\n')
             for line in additional_output:
                 line = line.strip()

=== added directory 'tests/lib/sysbench'
=== added file 'tests/lib/sysbench/__init__.py'
=== added file 'tests/lib/sysbench/sysbench_test_execution.py'
--- tests/lib/sysbench/sysbench_test_execution.py	1970-01-01 00:00:00 +0000
+++ tests/lib/sysbench/sysbench_test_execution.py	2011-06-01 23:31:52 +0000
@@ -0,0 +1,230 @@
+#! /usr/bin/env python
+# -*- mode: python; indent-tabs-mode: nil; -*-
+# vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+#
+# Copyright (C) 2010 Patrick Crews
+#
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+""" sysbench_test_execution:
+    code related to the execution of sysbench test cases 
+    
+    We are provided access to a testManager with 
+    sysbench-specific testCases.  
+
+"""
+
+# imports
+import os
+import re
+import sys
+import subprocess
+import commands
+
+import lib.test_mgmt.test_execution as test_execution
+
+class sysbenchTestExecutor(test_execution.testExecutor):
+    """ sysbench-specific testExecutor 
+        
+    """
+  
+    def execute_testCase (self):
+        """ Execute a sysbench testCase
+
+        """
+        test_execution.testExecutor.execute_testCase(self)
+        self.status = 0
+
+        # prepare the server for sysbench
+        self.prepare_sysbench()
+
+        # execute sysbench
+        self.execute_sysbench()
+
+        # analyze results
+        self.current_test_status = self.process_sysbench_output()
+        self.set_server_status(self.current_test_status)
+        self.server_manager.reset_servers(self.name)
+ 
+    def prepare_sysbench(self):
+        """ Prepare the server for a sysbench run
+            We use subprocess as we can pass os.environ dicts and whatnot 
+
+        """
+      
+        sysbench_outfile = os.path.join(self.logdir,'sysbench.out')
+        sysbench_output = open(sysbench_outfile,'w')
+        sysbench_cmd = ' '.join([self.current_testcase.test_command,'prepare'])      
+        self.logging.info("Preparing database for sysbench run...")
+        if self.debug:
+            self.logging.debug(sysbench_cmd)
+        sysbench_subproc = subprocess.Popen( sysbench_cmd
+                                         , shell=True
+                                         #, cwd=os.getcwd()
+                                         , env=self.working_environment
+                                         , stdout = sysbench_output
+                                         , stderr = subprocess.STDOUT
+                                         )
+        sysbench_subproc.wait()
+        retcode = sysbench_subproc.returncode
+
+        sysbench_output.close()
+        sysbench_file = open(sysbench_outfile,'r')
+        output = ''.join(sysbench_file.readlines())
+        sysbench_file.close()
+        if self.debug:
+            self.logging.debug("sysbench_retcode: %d" %(retcode))
+            self.logging.debug(output)
+        if retcode:
+            self.logging.error("sysbench_prepare failed with retcode %d:" %(retcode))
+            self.logging.error(output)   
+            sys.exit(1)
+            
+
+    
+
+    def execute_sysbench(self):
+        """ Execute the commandline and return the result.
+            We use subprocess as we can pass os.environ dicts and whatnot 
+
+        """
+      
+        testcase_name = self.current_testcase.fullname
+        self.time_manager.start(testcase_name,'test')
+        sysbench_outfile = os.path.join(self.logdir,'sysbench.out')
+        sysbench_output = open(sysbench_outfile,'w')
+        sysbench_cmd = ' '.join([self.current_testcase.test_command, 'run'])
+        self.logging.info("Executing sysbench:  %s" %(sysbench_cmd))
+        
+        sysbench_subproc = subprocess.Popen( sysbench_cmd
+                                         , shell=True
+                                         #, cwd=self.system_manager.sysbench_path
+                                         , env=self.working_environment
+                                         , stdout = sysbench_output
+                                         , stderr = subprocess.STDOUT
+                                         )
+        sysbench_subproc.wait()
+        retcode = sysbench_subproc.returncode     
+        execution_time = int(self.time_manager.stop(testcase_name)*1000) # millisec
+
+        sysbench_output.close()
+        sysbench_file = open(sysbench_outfile,'r')
+        output = ''.join(sysbench_file.readlines())
+        if self.debug:
+            self.logging.debug(output)
+        sysbench_file.close()
+
+        if self.debug:
+            self.logging.debug("sysbench_retcode: %d" %(retcode))
+        self.current_test_retcode = retcode
+        self.current_test_output = output
+        self.current_test_exec_time = execution_time
+
+    def process_sysbench_output(self):
+        """ sysbench has run, we now check out what we have 
+            We also output the data from the run
+        
+        """
+        # This slice code taken from drizzle-automation's sysbench handling
+        # Slice up the output report into a matrix and insert into the DB.
+        regexes= {
+          'tps': re.compile(r".*transactions\:\s+\d+\D*(\d+\.\d+).*")
+        , 'deadlocksps': re.compile(r".*deadlocks\:\s+\d+\D*(\d+\.\d+).*")
+        , 'rwreqps': re.compile(r".*read\/write\s+requests\:\s+\d+\D*(\d+\.\d+).*")
+        , 'min_req_lat_ms': re.compile(r".*min\:\s+(\d*\.\d+)ms.*")
+        , 'max_req_lat_ms': re.compile(r".*max\:\s+(\d*\.\d+)ms.*")
+        , 'avg_req_lat_ms': re.compile(r".*avg\:\s+(\d*\.\d+)ms.*")
+        , '95p_req_lat_ms': re.compile(r".*approx.\s+95\s+percentile\:\s+(\d+\.\d+)ms.*")
+        }
+        run= {}
+        for line in self.current_test_output.split("\n"):
+            for key in regexes.keys():
+                result= regexes[key].match(line)
+                if result:
+                    run[key]= float(result.group(1)) # group(0) is entire match...
+        # we set our test output to the regex'd-up data
+        # we also make it a single string, separated by newlines
+        self.current_test_output = str(run)[1:-1].replace(',','\n').replace("'",'')
+                    
+        if self.current_test_retcode == 0:
+            return 'pass'
+        else:
+            return 'fail'
+
+    def handle_system_reqs(self):
+        """ We check our test case and see what we need to do
+            system-wise to get ready.  This is likely to be 
+            mode-dependent and this is just a placeholder
+            method
+
+        """
+
+        self.process_environment_reqs()
+        self.process_symlink_reqs()
+        self.process_master_sh()  
+        return
+
+    def process_master_sh(self):
+        """ We do what we need to if we have a master.sh file """
+        if self.current_testcase.master_sh:
+            retcode, output = self.system_manager.execute_cmd("/bin/sh %s" %(self.current_testcase.master_sh))
+            if self.debug:
+                self.logging.info("retcode: %retcode")
+                self.logging.info("%output")
+
+    def process_environment_reqs(self):
+        """ We generate the ENV vars we need set
+            and then ask systemManager to do so
+
+        """
+        env_reqs = {  'DRIZZLETEST_VARDIR': self.master_server.vardir
+                   ,  'DRIZZLE_TMP_DIR': self.master_server.tmpdir
+                   ,  'MASTER_MYSOCK': self.master_server.socket_file
+                   ,  'MASTER_MYPORT': str(self.master_server.master_port)
+                   ,  'MC_PORT': str(self.master_server.mc_port)
+                   ,  'PBMS_PORT': str(self.master_server.pbms_port)
+                   ,  'RABBITMQ_NODE_PORT': str(self.master_server.rabbitmq_node_port)
+                   ,  'DRIZZLE_TCP_PORT': str(self.master_server.drizzle_tcp_port)
+                   ,  'EXE_DRIZZLE': self.master_server.drizzle_client
+                   ,  'MASTER_SERVER_SLAVE_CONFIG' : self.master_server.slave_config_file
+                   ,  'DRIZZLE_DUMP': "%s --no-defaults -uroot -p%d" %( self.master_server.drizzledump
+                                                        , self.master_server.master_port)
+                   ,  'DRIZZLE_SLAP': "%s -uroot -p%d" %( self.master_server.drizzleslap
+                                                        , self.master_server.master_port)
+                   ,  'DRIZZLE_IMPORT': "%s -uroot -p%d" %( self.master_server.drizzleimport
+                                                          , self.master_server.master_port)
+                   ,  'DRIZZLE': "%s -uroot -p%d" %( self.master_server.drizzle_client
+                                                   , self.master_server.master_port)
+                   ,  'DRIZZLE_ADMIN' : "%s -uroot -p%d" %( self.master_server.drizzleadmin
+                                                         , self.master_server.master_port)
+                   ,  'DRIZZLE_BASEDIR' : self.system_manager.code_tree.basedir
+                   ,  'DRIZZLE_TRX_READER' : self.system_manager.code_tree.drizzle_trx_reader
+                   }     
+
+
+        self.working_environment = self.system_manager.create_working_environment(env_reqs)
+
+
+    def process_symlink_reqs(self):
+        """ Create any symlinks we may need """
+        needed_symlinks = []
+
+        self.system_manager.create_symlinks(needed_symlinks)
+
+    
+   
+
+        

=== added file 'tests/lib/sysbench/sysbench_test_management.py'
--- tests/lib/sysbench/sysbench_test_management.py	1970-01-01 00:00:00 +0000
+++ tests/lib/sysbench/sysbench_test_management.py	2011-06-01 23:31:52 +0000
@@ -0,0 +1,165 @@
+#! /usr/bin/env python
+# -*- mode: python; indent-tabs-mode: nil; -*-
+# vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+#
+# Copyright (C) 2010 Patrick Crews
+#
+## This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+""" sysbench_test_management:
+    code related to the gathering / analysis / management of 
+    the test cases
+    ie - collecting the list of tests in each suite, then
+    gathering additional, relevant information for sysbench mode
+
+"""
+
+# imports
+import os
+import re
+import sys
+from ConfigParser import RawConfigParser
+
+import lib.test_mgmt.test_management as test_management
+
+
+    
+class testCase:
+    """Holds info on a single sysbench test
+ 
+    """
+    def __init__( self, system_manager, name=None
+                , fullname = None, server_requirements=[[]]
+                , comment=None, test_command=None, cnf_path=None
+                , debug=False ):
+        self.system_manager = system_manager
+        self.logging = self.system_manager.logging
+        self.skip_keys = ['system_manager','logging']
+        self.name = name
+        self.fullname = fullname
+        self.suitename = 'sysbench_tests'
+        self.master_sh = None
+        self.comment = comment
+        self.server_requirements = server_requirements
+        self.test_command = test_command
+        self.cnf_path = cnf_path
+        
+        if debug:
+            self.system_manager.logging.debug_class(self)
+
+    def should_run(self):
+        if self.skip_flag or self.disable:
+            return 0
+        else:
+            return 1
+
+ 
+        
+        
+          
+class testManager(test_management.testManager):
+    """Deals with scanning test directories, gathering test cases, and 
+       collecting per-test information (opt files, etc) for use by the
+       test-runner
+
+    """
+
+    def __init__(self, verbose, debug, default_engine, dotest, skiptest
+                , reorder, suitelist, suitepaths, system_manager
+                , test_cases, mode):
+        super(testManager, self).__init__( verbose, debug, default_engine
+                                         , dotest, skiptest, reorder
+                                         , suitelist, suitepaths
+                                         , system_manager, test_cases, mode)
+        self.suitepaths = [os.path.join(self.testdir,'sysbench_tests')]
+        if suitelist is None:
+            self.suitelist = ['readonly']
+        else:
+            self.suitelist = suitelist
+
+    def process_suite(self,suite_dir):
+        """Process a test suite.
+           Look for sysbench tests, which are nice clean conf files
+        
+        """
+
+        # We know this based on how we organize sysbench test conf files
+        suite_name = os.path.basename(suite_dir) 
+        if self.verbose:
+                self.system_manager.logging.verbose("Processing suite: %s" %(suite_name))
+        testlist = [os.path.join(suite_dir,test_file) for test_file in sorted(os.listdir(suite_dir)) if test_file.endswith('.cnf')]
+
+        # Search for specific test names
+        if self.desired_tests: # We have specific, named tests we want from the suite(s)
+           tests_to_use = []
+           for test in self.desired_tests:
+               if test.endswith('.cnf'): 
+                   pass
+               else:
+                   test = test+'.cnf'
+               test = os.path.join(suite_dir,test)
+               if test in testlist:
+                   tests_to_use.append(test)
+           testlist = tests_to_use
+        for test_case in testlist:
+            self.add_test(self.process_test_file(suite_name, test_case))
+
+
+    def process_test_file(self, suite_name, testfile):
+        """ We convert the info in a testfile into a testCase object """
+
+        config_reader = RawConfigParser()
+        config_reader.read(testfile)
+        # test_name = filename - .cnf...simpler
+        test_name = os.path.basename(testfile).replace('.cnf','')
+        test_comment = config_reader.get('test_info','comment')
+        server_requirements = self.process_server_reqs(config_reader.get('test_servers','servers'))
+        test_command = config_reader.get('test_command','command')
+        return testCase( self.system_manager
+                       , name = test_name
+                       , fullname = "%s.%s" %(suite_name, test_name)
+                       , server_requirements = server_requirements
+                       , test_command = test_command
+                       , cnf_path = testfile
+                       , debug = self.debug )
+
+        #sys.exit(0)
+
+    def process_server_reqs(self,data_string):
+        """ We read in the list of lists as a string, so we need to 
+            handle this / break it down into proper chunks
+
+        """
+        server_reqs = []
+        # We expect to see a list of lists and throw away the 
+        # enclosing brackets
+        option_sets = data_string[1:-1].strip().split(',')
+        for option_set in option_sets:
+            server_reqs.append([option_set[1:-1].strip()])
+        return server_reqs
+
+    def record_test_result(self, test_case, test_status, output, exec_time):
+        """ Accept the results of an executed testCase for further
+            processing.
+ 
+        """
+        if test_status not in self.executed_tests:
+            self.executed_tests[test_status] = [test_case]
+        else:
+            self.executed_tests[test_status].append(test_case)
+        # report
+        self.logging.test_report( test_case.fullname, test_status
+                                , str(exec_time), output
+                                , report_output= True)

=== modified file 'tests/lib/test_mgmt/test_management.py'
--- tests/lib/test_mgmt/test_management.py	2011-03-17 06:31:49 +0000
+++ tests/lib/test_mgmt/test_management.py	2011-06-01 23:31:52 +0000
@@ -198,9 +198,15 @@
             self.executed_tests[test_status] = [test_case]
         else:
             self.executed_tests[test_status].append(test_case)
-        # report
+        # report.  If the test failed, we print any additional
+        # output returned by the test executor
+        # We may want to report additional output at other times
+        if test_status != 'pass':
+            report_output = True
+        else:
+            report_output = False
         self.logging.test_report( test_case.fullname, test_status
-                                , exec_time, output)
+                                , exec_time, output, report_output)
 
 
     def print_test_list(self):

=== modified file 'tests/lib/test_mode.py'
--- tests/lib/test_mode.py	2011-03-17 06:31:49 +0000
+++ tests/lib/test_mode.py	2011-06-01 23:31:52 +0000
@@ -43,10 +43,8 @@
         # We are just setting the code up this way to hopefully make
         # other coolness easier in the future
 
-        # get our mode-specific testManager
+        # get our mode-specific testManager and Executor
         from drizzle_test_run.dtr_test_management import testManager
- 
-        # get our mode-specific testExecutor
         from drizzle_test_run.dtr_test_execution import testExecutor as testExecutor
 
     elif test_mode == 'randgen':
@@ -57,6 +55,14 @@
         from randgen.randgen_test_management import testManager
         from randgen.randgen_test_execution import randgenTestExecutor as testExecutor
 
+    elif test_mode == 'sysbench':
+        # sysbench mode - we have a standard server setup 
+        # and a variety of concurrencies we want to run
+
+        # get manager and executor
+        from sysbench.sysbench_test_management import testManager
+        from sysbench.sysbench_test_execution import sysbenchTestExecutor as testExecutor
+
     elif test_mode == 'cleanup':
         # cleanup mode - we try to kill any servers whose pid's we detect
         # in our workdir.  Might extend to other things (file cleanup, etc)

=== added directory 'tests/sysbench_tests'
=== added directory 'tests/sysbench_tests/readonly'
=== added file 'tests/sysbench_tests/readonly/concurrency_1024.cnf'
--- tests/sysbench_tests/readonly/concurrency_1024.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readonly/concurrency_1024.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=on --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=1024
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

=== added file 'tests/sysbench_tests/readonly/concurrency_128.cnf'
--- tests/sysbench_tests/readonly/concurrency_128.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readonly/concurrency_128.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=on --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=128
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

=== added file 'tests/sysbench_tests/readonly/concurrency_16.cnf'
--- tests/sysbench_tests/readonly/concurrency_16.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readonly/concurrency_16.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=on --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=16
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

=== added file 'tests/sysbench_tests/readonly/concurrency_256.cnf'
--- tests/sysbench_tests/readonly/concurrency_256.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readonly/concurrency_256.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=on --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=256
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

=== added file 'tests/sysbench_tests/readonly/concurrency_32.cnf'
--- tests/sysbench_tests/readonly/concurrency_32.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readonly/concurrency_32.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=on --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=32
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

=== added file 'tests/sysbench_tests/readonly/concurrency_512.cnf'
--- tests/sysbench_tests/readonly/concurrency_512.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readonly/concurrency_512.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=on --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=512
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

=== added file 'tests/sysbench_tests/readonly/concurrency_64.cnf'
--- tests/sysbench_tests/readonly/concurrency_64.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readonly/concurrency_64.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=on --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=64
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

=== added directory 'tests/sysbench_tests/readwrite'
=== added file 'tests/sysbench_tests/readwrite/concurrency_1024.cnf'
--- tests/sysbench_tests/readwrite/concurrency_1024.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readwrite/concurrency_1024.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=off --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=1024
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

=== added file 'tests/sysbench_tests/readwrite/concurrency_128.cnf'
--- tests/sysbench_tests/readwrite/concurrency_128.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readwrite/concurrency_128.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=off --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=128
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

=== added file 'tests/sysbench_tests/readwrite/concurrency_16.cnf'
--- tests/sysbench_tests/readwrite/concurrency_16.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readwrite/concurrency_16.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=off --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=16
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

=== added file 'tests/sysbench_tests/readwrite/concurrency_256.cnf'
--- tests/sysbench_tests/readwrite/concurrency_256.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readwrite/concurrency_256.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=off --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=256
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

=== added file 'tests/sysbench_tests/readwrite/concurrency_32.cnf'
--- tests/sysbench_tests/readwrite/concurrency_32.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readwrite/concurrency_32.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=off --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=32
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

=== added file 'tests/sysbench_tests/readwrite/concurrency_512.cnf'
--- tests/sysbench_tests/readwrite/concurrency_512.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readwrite/concurrency_512.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=off --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=512
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

=== added file 'tests/sysbench_tests/readwrite/concurrency_64.cnf'
--- tests/sysbench_tests/readwrite/concurrency_64.cnf	1970-01-01 00:00:00 +0000
+++ tests/sysbench_tests/readwrite/concurrency_64.cnf	2011-06-01 23:31:52 +0000
@@ -0,0 +1,8 @@
+[test_info]
+comment = 16 threads
+
+[test_command]
+command = sysbench --max-time=240 --max-requests=0 --test=oltp --db-ps-mode=disable --drizzle-table-engine=innodb --oltp-read-only=off --oltp-table-size=1000000 --drizzle-mysql=on --drizzle-user=root --drizzle-db=test --drizzle-port=$MASTER_MYPORT --drizzle-host=localhost --db-driver=drizzle --num-threads=64
+
+[test_servers]
+servers = [[innodb.buffer-pool-size=256M innodb.log-file-size=64M innodb.log-buffer-size=8M innodb.thread-concurrency=0 innodb.additional-mem-pool-size=16M table-open-cache=4096 table-definition-cache=4096 mysql-protocol.max-connections=2048]]

